@@ -4,7 +4,7 @@ import requests
 import time
 from collections import namedtuple
 
-from .exceptions import SocketIOConnectionError, _TimeoutError, _PacketError
+from .exceptions import ConnectionError, TimeoutError, PacketError
 from .transports import _get_response, _negotiate_transport, TRANSPORTS
 
 
@@ -168,12 +168,12 @@ class SocketIO(object):
                         for packet in self._transport.recv_packet():
                             try:
                                 self._process_packet(packet)
-                            except _PacketError as e:
+                            except PacketError as e:
                                 _log.warn('[packet error] %s', e)
-                    except _TimeoutError:
+                    except TimeoutError:
                         pass
                     self.heartbeat_pacemaker.send(elapsed_time)
-                except SocketIOConnectionError as e:
+                except ConnectionError as e:
                     try:
                         warning = Exception('[connection error] %s' % e)
                         warning_screen.throw(warning)
@@ -210,7 +210,7 @@ class SocketIO(object):
             try:
                 self.__transport = self._get_transport()
                 break
-            except SocketIOConnectionError as e:
+            except ConnectionError as e:
                 if not self.wait_for_connection:
                     raise
                 try:
@@ -250,13 +250,13 @@ class SocketIO(object):
         code, packet_id, path, data = packet
         namespace = self.get_namespace(path)
         delegate = self._get_delegate(code)
-        delegate(packet_id, data, namespace._find_event_callback)
+        delegate(packet, namespace._find_event_callback)
 
     def get_namespace(self, path=''):
         try:
             return self._namespace_by_path[path]
         except KeyError:
-            raise _PacketError('unexpected namespace path (%s)' % path)
+            raise PacketError('unexpected namespace path (%s)' % path)
 
     def _get_delegate(self, code):
         try:
@@ -272,38 +272,42 @@ class SocketIO(object):
                 '8': self._on_noop,
             }[code]
         except KeyError:
-            raise _PacketError('unexpected code (%s)' % code)
+            raise PacketError('unexpected code (%s)' % code)
 
-    def _on_disconnect(self, packet_id, data, find_event_callback):
+    def _on_disconnect(self, packet, find_event_callback):
         find_event_callback('disconnect')()
 
-    def _on_connect(self, packet_id, data, find_event_callback):
+    def _on_connect(self, packet, find_event_callback):
         find_event_callback('connect')()
 
-    def _on_heartbeat(self, packet_id, data, find_event_callback):
+    def _on_heartbeat(self, packet, find_event_callback):
         find_event_callback('heartbeat')()
 
-    def _on_message(self, packet_id, data, find_event_callback):
+    def _on_message(self, packet, find_event_callback):
+        code, packet_id, path, data = packet
         args = [data]
         if packet_id:
-            args.append(self._prepare_to_send_ack(packet_id))
+            args.append(self._prepare_to_send_ack(path, packet_id))
         find_event_callback('message')(*args)
 
-    def _on_json(self, packet_id, data, find_event_callback):
+    def _on_json(self, packet, find_event_callback):
+        code, packet_id, path, data = packet
         args = [json.loads(data)]
         if packet_id:
-            args.append(self._prepare_to_send_ack(packet_id))
+            args.append(self._prepare_to_send_ack(path, packet_id))
         find_event_callback('message')(*args)
 
-    def _on_event(self, packet_id, data, find_event_callback):
+    def _on_event(self, packet, find_event_callback):
+        code, packet_id, path, data = packet
         value_by_name = json.loads(data)
         event = value_by_name['name']
         args = value_by_name.get('args', [])
         if packet_id:
-            args.append(self._prepare_to_send_ack(packet_id))
+            args.append(self._prepare_to_send_ack(path, packet_id))
         find_event_callback(event)(*args)
 
-    def _on_ack(self, packet_id, data, find_event_callback):
+    def _on_ack(self, packet, find_event_callback):
+        code, packet_id, path, data = packet
         data_parts = data.split('+', 1)
         packet_id = data_parts[0]
         try:
@@ -313,16 +317,17 @@ class SocketIO(object):
         args = json.loads(data_parts[1]) if len(data_parts) > 1 else []
         ack_callback(*args)
 
-    def _on_error(self, packet_id, data, find_event_callback):
+    def _on_error(self, packet, find_event_callback):
+        code, packet_id, path, data = packet
         reason, advice = data.split('+', 1)
         find_event_callback('error')(reason, advice)
 
-    def _on_noop(self, packet_id, data, find_event_callback):
+    def _on_noop(self, packet, find_event_callback):
         find_event_callback('noop')()
 
-    def _prepare_to_send_ack(self, packet_id):
+    def _prepare_to_send_ack(self, path, packet_id):
         'Return function that acknowledges the server'
-        return lambda *args: self._transport.ack(packet_id, *args)
+        return lambda *args: self._transport.ack(path, packet_id, *args)
 
 
 def find_callback(args, kw=None):
@@ -361,8 +366,8 @@ def _get_socketIO_session(secure, base_url, **kw):
     server_url = '%s://%s/' % ('https' if secure else 'http', base_url)
     try:
         response = _get_response(requests.get, server_url, **kw)
-    except _TimeoutError as e:
-        raise SocketIOConnectionError(e)
+    except TimeoutError as e:
+        raise ConnectionError(e)
     response_parts = response.text.split(':')
     return _SocketIOSession(
         id=response_parts[0],
